==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/id-ID/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Kolom Tambahan',
    'manage'                    => 'Kelola',
    'field'		                => 'Kolom',
    'about_fieldsets_title'		=> 'Tentang Set Kolom',
    'about_fieldsets_text'		=> 'Fieldsets memungkinkan Anda untuk membuat kolom tambahan yang seringkali dipakai untuk dapat digunakan pada model aset tertentu.',
    'custom_format'             => 'Format Tambahan...',
    'encrypt_field'      	        => 'Enkripsi nilai kolom ini di database',
    'encrypt_field_help'      => 'PERINGATAN: Mengenkripsi kolom menjadikan tidak bisa ditemukan.',
    'encrypted'      	        => 'Dienkripsi',
    'fieldset'      	        => 'Set Kolom',
    'qty_fields'      	      => 'Kolom Jumlah',
    'fieldsets'      	        => 'Kumpulan Set Kolom',
    'fieldset_name'           => 'Nama Kumpulan Set Kolom',
    'field_name'              => 'Nama Set Kolom',
    'field_values'            => 'Nilai Kolom',
    'field_values_help'       => 'Tambahkan opsi pilihan, satu opsi per baris. Baris kosong selain baris pertama akan diabaikan.',
    'field_element'           => 'Elemen Form',
    'field_element_short'     => 'Elemen',
    'field_format'            => 'Format',
    'field_custom_format'     => 'Format Ubahan',
    'field_custom_format_help'     => 'Kolom ini memungkinkan Anda menggunakan ekspresi regex untuk validasi. Ini harus dimulai dengan "regex:" - misalnya, untuk memvalidasi bahwa nilai kolom kustom berisi IMEI yang valid (15 angka numerik), Anda dapat menggunakan <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Harus diisi',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Digunakan oleh Model',
    'order'   		            => 'Urutan',
    'create_fieldset'         => 'Set Kolom Baru',
    'update_fieldset'         => 'Update Fieldset',
    'fieldset_does_not_exist'   => 'Fieldset :id does not exist',
    'fieldset_updated'         => 'Fieldset updated',
    'create_fieldset_title' => 'Buat fieldset baru',
    'create_field'            => 'Tambah Kolom Ubahan',
    'create_field_title' => 'Buat field kustom',
    'value_encrypted'      	        => 'Nilai dari kolom ini di database dienkripsi. hanya pengguna admin yang bisa melihat nilai deskripsinya',
    'show_in_email'     => 'Sertakan nilai bidang ini dalam email checkout yang dikirim kepada pengguna? Bidang terenkripsi tidak dapat dimasukkan dalam email',
    'show_in_email_short'     => 'Include in emails.',
    'help_text' => 'Teks bantuan',
    'help_text_description' => 'Ini adalah teks opsional yang akan muncul di bawah elemen formulir saat mengedit aset untuk memberikan konteks pada field.',
    'about_custom_fields_title' => 'Lihat field kustom',
    'about_custom_fields_text' => 'Field khusus memungkinkan Anda menambahkan atribut arbitrer ke aset.',
    'add_field_to_fieldset' => 'Tambahkan Field ke dalam Fieldset',
    'make_optional' => 'Diperlukan - klik untuk ubah menjadi opsional',
    'make_required' => 'Opsional - klik untuk ubah menjadi Diperlukan',
    'reorder' => 'Susun ulang',
    'db_field' => 'Field Database',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code>:db_column</code> but should be <code>:expected</code>.',
    'is_unique' => 'Nilai ini harus unik di semua aset',
    'unique' => 'Unik',
    'display_in_user_view' => 'Allow the checked out user to view these values in their View Assigned Assets page',
    'display_in_user_view_table' => 'Visible to User',
    'auto_add_to_fieldsets' => 'Automatically add this to every new fieldset',
    'add_to_preexisting_fieldsets' => 'Add to any existing fieldsets',
    'show_in_listview' => 'Show in list views by default. Authorized users will still be able to show/hide via the column selector',
    'show_in_listview_short' => 'Show in lists',
    'show_in_requestable_list_short' => 'Show in requestable assets list',
    'show_in_requestable_list' => 'Show value in requestable assets list. Encrypted fields will not be shown',
    'encrypted_options' => 'This field is encrypted, so some display options will not be available.',

];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/id-ID/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Kolom Tambahan',
    'manage'                    => 'Kelola',
    'field'		                => 'Kolom',
    'about_fieldsets_title'		=> 'Tentang Set Kolom',
    'about_fieldsets_text'		=> 'Fieldsets memungkinkan Anda untuk membuat kolom tambahan yang seringkali dipakai untuk dapat digunakan pada model aset tertentu.',
    'custom_format'             => 'Format Tambahan...',
    'encrypt_field'      	        => 'Enkripsi nilai kolom ini di database',
    'encrypt_field_help'      => 'PERINGATAN: Mengenkripsi kolom menjadikan tidak bisa ditemukan.',
    'encrypted'      	        => 'Dienkripsi',
    'fieldset'      	        => 'Set Kolom',
    'qty_fields'      	      => 'Kolom Jumlah',
    'fieldsets'      	        => 'Kumpulan Set Kolom',
    'fieldset_name'           => 'Nama Kumpulan Set Kolom',
    'field_name'              => 'Nama Set Kolom',
    'field_values'            => 'Nilai Kolom',
    'field_values_help'       => 'Tambahkan opsi pilihan, satu opsi per baris. Baris kosong selain baris pertama akan diabaikan.',
    'field_element'           => 'Elemen Form',
    'field_element_short'     => 'Elemen',
    'field_format'            => 'Format',
    'field_custom_format'     => 'Format Ubahan',
    'field_custom_format_help'     => 'Kolom ini memungkinkan Anda menggunakan ekspresi regex untuk validasi. Ini harus dimulai dengan "regex:" - misalnya, untuk memvalidasi bahwa nilai kolom kustom berisi IMEI yang valid (15 angka numerik), Anda dapat menggunakan <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Harus diisi',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Digunakan oleh Model',
    'order'   		            => 'Urutan',
    'create_fieldset'         => 'Set Kolom Baru',
    'update_fieldset'         => 'Perbarui Kelompok Kolom',
    'fieldset_does_not_exist'   => 'Kelompok Kolom :id tidak ada',
    'fieldset_updated'         => 'Kelompok Kolom telah diperbarui',
    'create_fieldset_title' => 'Buat fieldset baru',
    'create_field'            => 'Tambah Kolom Ubahan',
    'create_field_title' => 'Buat field kustom',
    'value_encrypted'      	        => 'Nilai dari kolom ini di database dienkripsi. hanya pengguna admin yang bisa melihat nilai deskripsinya',
    'show_in_email'     => 'Sertakan nilai bidang ini dalam email checkout yang dikirim kepada pengguna? Bidang terenkripsi tidak dapat dimasukkan dalam email',
    'show_in_email_short'     => 'Sertakan dalam email.',
    'help_text' => 'Teks bantuan',
    'help_text_description' => 'Ini adalah teks opsional yang akan muncul di bawah elemen formulir saat mengedit aset untuk memberikan konteks pada field.',
    'about_custom_fields_title' => 'Lihat field kustom',
    'about_custom_fields_text' => 'Field khusus memungkinkan Anda menambahkan atribut arbitrer ke aset.',
    'add_field_to_fieldset' => 'Tambahkan Field ke dalam Fieldset',
    'make_optional' => 'Diperlukan - klik untuk ubah menjadi opsional',
    'make_required' => 'Opsional - klik untuk ubah menjadi Diperlukan',
    'reorder' => 'Susun ulang',
    'db_field' => 'Field Database',
    'db_convert_warning' => 'PERINGATAN. Kolom ini ada di tabel custom fields sebagai <code>:db_column</code> tetapi seharusnya <code>:expected</code>.',
    'is_unique' => 'Nilai ini harus unik di semua aset',
    'unique' => 'Unik',
    'display_in_user_view' => 'Izinkan pengguna yang meminjam untuk melihat nilai ini di halaman Lihat Aset yang Terkait atau Sedang Diberikan',
    'display_in_user_view_table' => 'Dapat dilihat oleh Pengguna',
    'auto_add_to_fieldsets' => 'Tambahkan ini secara otomatis ke setiap kelompok kolom baru',
    'add_to_preexisting_fieldsets' => 'Tambahkan ke semua kelompok kolom yang ada',
    'show_in_listview' => 'Tampilkan di tampilan daftar secara default. Pengguna yang berwenang tetap dapat menampilkan/menyembunyikan melalui pemilih kolom',
    'show_in_listview_short' => 'Tampilkan dalam daftar',
    'show_in_requestable_list_short' => 'Tampilkan di daftar aset yang dapat diminta',
    'show_in_requestable_list' => 'Tampilkan nilai di daftar aset yang dapat diminta. Kolom yang dienkripsi tidak akan ditampilkan',
    'encrypted_options' => 'Kolom ini dienkripsi, sehingga beberapa opsi tampilan tidak akan tersedia.',

];
